__vendor_info__ = {
    'alibaba': ('api_key',),
    'baidu': ('app_id',),
    'deepseek': ('api_key',),
    'google': ('api_key',),
    'tencent': ('secret_id', 'secret_key'), # https://console.cloud.tencent.com/cam/capi
    'xunfei': ('api_key', 'service_key'),
    'zhipu': ('api_key',),
}